Platform agnostic support
Modules
- collections
alloc - Collection types and utilities for working with collections in a platform-agnostic way.
- hash
- Provides replacements for
std::hashitems usingfoldhash. - string
- Platform-agnostic impls to
stringitems - sync
- Provides various synchronization alternatives to language primitives.
- time
- Provides
Instantfor all platforms. - utils
- General utilities for first-party obel engine crates.
- vec
- Platform-agnostic impls to
vecitems
Macros
- run_
once - A macro that ensures the given expression is executed exactly once per call site.